PRAGMA foreign_keys=OFF;
BEGIN TRANSACTION;
CREATE TABLE experiment_run (
      run_id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER,
      chunk_unit TEXT NOT NULL,
      chunk_size INTEGER NOT NULL,
      completed INTEGER NOT NULL,
      total INTEGER NOT NULL,
      failed INTEGER NOT NULL,
      queuing INTEGER NOT NULL,
      running INTEGER NOT NULL,
      submitted INTEGER NOT NULL,
      suspended INTEGER NOT NULL DEFAULT 0,
      metadata TEXT
      );
INSERT INTO experiment_run VALUES(1,'2023-09-19-14:49:42','2023-09-19-14:56:52',1695127782,1695128212,'month',12,0,261,1,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "eferre1", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "CMOR_WRAPPER": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(2,'2023-09-19-14:56:52','2023-09-19-15:00:17',1695128212,1695128417,'month',12,0,261,0,0,1,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "CMOR_WRAPPER": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(3,'2023-09-19-15:00:17','2023-09-19-15:00:30',1695128417,1695128430,'month',12,0,261,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "CMOR_WRAPPER": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(4,'2023-09-19-15:00:30','2023-09-19-15:09:13',1695128430,1695128953,'month',12,65,261,0,1,0,1,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "CMOR_WRAPPER": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(5,'2023-09-19-15:09:13','2023-09-19-15:09:57',1695128953,1695128997,'month',12,0,261,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "CMOR_WRAPPER": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(6,'2023-09-19-15:09:58','2023-09-19-15:10:56',1695128998,1695129056,'month',12,0,261,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(7,'2023-09-19-15:10:56','2023-09-19-15:11:32',1695129056,1695129092,'month',12,0,261,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "128", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(8,'2023-09-19-15:11:32','2023-09-19-15:12:35',1695129092,1695129155,'month',12,0,261,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "128", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(9,'2023-09-19-15:12:35','2023-09-19-15:26:58',1695129155,1695130018,'month',12,0,261,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "128", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(10,'2023-09-19-15:26:58','2023-09-19-15:35:13',1695130018,1695130513,'month',12,0,261,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "128", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(11,'2023-09-19-15:35:13','2023-09-19-15:35:23',1695130513,1695130523,'month',12,0,261,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "128", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(12,'2023-09-19-15:35:23','2023-09-19-15:55:18',1695130523,1695131718,'month',12,0,261,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "128", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
INSERT INTO experiment_run VALUES(13,'2023-09-19-15:55:18','2023-09-19-15:55:18',1695131718,0,'month',12,0,261,0,0,0,0,0,'{"platforms": {"meluxina_data_transfer": {"MAX_WALLCLOCK": "48:00", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "nord3v2": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "nord1.bsc.es", "USER": "bsc32070", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "False"}, "meluxina": {"QUEUE": "default", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROCESSORS_PER_NODE": "128", "PROJECT": "p200191", "SCRATCH_DIR": "/project/home", "HOST": "meluxina_autosubmit", "USER": "u100498", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "marenostrum4": {"QUEUE": "bsc_es", "MAX_WALLCLOCK": "48:00", "PROCESSORS_PER_NODE": "128", "PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "mn1.bsc.es", "USER": "bsc32070", "MAX_PROCESSORS": "128", "TYPE": "slurm", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node_bscearth000": {"QUEUE": "serial", "PROJECT": "Earth", "SCRATCH_DIR": "/esarchive/scratch", "HOST": "bscearth000", "USER": "dbeltran", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "transfer_node": {"PROJECT": "bsc32", "SCRATCH_DIR": "/gpfs/scratch", "HOST": "dt01.bsc.es", "USER": "bsc32070", "TYPE": "ps", "ADD_PROJECT_TO_HOST": "false"}, "ecmwf-xc40": {"QUEUE": "np", "SERIAL_QUEUE": "ns", "MAX_WALLCLOCK": "48:00", "BUDGET": "", "PROJECT": "spesiccf", "SCRATCH_DIR": "/scratch/ms", "HOST": "cca", "VERSION": "pbs", "USER": "c3ef", "TYPE": "ecaccess", "ADD_PROJECT_TO_HOST": "false"}}, "jobs": {"NCTIME": {"WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "10", "FILE": "templates/nctime.tmpl.sh", "DEPENDENCIES": "NCTIME-1 CLEAN CLEAN-1 CLEAN-2 CLEAN-3", "CHECK": "true"}, "ESMVALTOOL": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN", "FILE": "templates/esmvaltool.tmpl.py", "TYPE": "python", "CHECK": "true"}, "CMORATM": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "RUNNING": "chunk", "DEPENDENCIES": "SIM SIM+1", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN_EXPERIMENT": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "once", "DEPENDENCIES": "NCTIME TRANSFER_MEMBER EARTHDIAGS MONITOR", "FILE": "templates/clean_experiment.tmpl.sh", "CHECK": "true"}, "CMOROCE": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "1:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "EARTHDIAGS": {"CUSTOM_DIRECTIVES": "[\"#SBATCH --exclusive\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN EARTHDIAGS-1", "FILE": "templates/earthdiags.tmpl.sh", "CHECK": "true"}, "CMORLPJG": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CMORTM5": {"CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "2:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/cmor.tmpl.sh", "CHECK": "true"}, "CLEAN": {"WALLCLOCK": "00:30", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "chunk", "DEPENDENCIES": "CLEAN POST SIM SIM+1 CMOROCE CMORATM CMORATM+1", "FILE": "templates/clean.tmpl.sh", "SELECT_CHUNKS": "CLEAN*[1]*[2:]", "CHECK": "true"}, "CLEAN_MEMBER": {"WALLCLOCK": "02:00", "NOTIFY_ON": "FAILED", "PLATFORM": "marenostrum4", "RUNNING": "member", "DEPENDENCIES": "CLEAN SAVEIC", "FILE": "templates/clean_member.tmpl.sh", "CHECK": "true"}, "SAVEIC": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "SIM", "FILE": "templates/saveic.tmpl.sh", "CHECK": "true"}, "POST": {"PROCESSORS": "12", "CUSTOM_DIRECTIVES": "[\"#SBATCH -N 1\", \"#SBATCH --hint=nomultithread\"]", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "RUNNING": "chunk", "DEPENDENCIES": "CMORATM CMORATM+1 CMOROCE CMORLPJG CMORTM5 SAVEIC SIM SIM+1 POST-1", "FILE": "templates/post.tmpl.sh", "CHECK": "true"}, "TRANSFER_MEMBER": {"NOTIFY_ON": "FAILED", "PLATFORM": "transfer_node_bscearth000", "RUNNING": "member", "DEPENDENCIES": "CLEAN_MEMBER", "FILE": "templates/transfer_member.tmpl.sh", "CHECK": "true"}, "SIM": {"WALLCLOCK": "0:02", "NOTIFY_ON": "FAILED", "PLATFORM": "LOCAL", "RUNNING": "chunk", "DEPENDENCIES": "INI SIM-1 CLEAN-10 NCTIME-10", "FILE": "templates/fake_sim.tmpl.sh", "CHECK": "on_submission"}, "MONITOR": {"PROCESSORS": "4", "WALLCLOCK": "01:00", "NOTIFY_ON": "FAILED", "PLATFORM": "nord3v2", "RUNNING": "chunk", "FREQUENCY": "5", "FILE": "templates/monitor.tmpl.py", "DEPENDENCIES": "MONITOR-5 CLEAN ESMVALTOOL EARTHDIAGS", "TYPE": "python", "CHECK": "true"}}, "exp": {"svn": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_REVISION": "", "PROJECT_URL": ""}, "git": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_BRANCH": "1844-Porting_to_meluxina", "PROJECT_SUBMODULES_DEPTH": "10", "PROJECT_COMMIT": "", "FETCH_SINGLE_BRANCH": "true", "PROJECT_SUBMODULES": "", "PROJECT_ORIGIN": "https://earth.bsc.es/gitlab/es/auto-ecearth3.git"}, "project": {"HPCARCH": "marenostrum4", "EXPID": "a01c", "PROJECT_DESTINATION": "auto-ecearth3", "PROJECT_TYPE": "none"}, "experiment": {"HPCARCH": "marenostrum4", "CHUNKSIZEUNIT": "month", "CHUNKSIZE": "12", "NUMCHUNKS": "25", "DATELIST": "18500101", "EXPID": "a01c", "MEMBERS": "fc0", "CALENDAR": "standard"}, "project_files": {"FILE_JOBS_CONF": "", "HPCARCH": "marenostrum4", "EXPID": "a01c", "FILE_PROJECT_CONF": ""}, "rerun": {"HPCARCH": "marenostrum4", "CHUNKLIST": "", "EXPID": "a01c", "RERUN": "FALSE"}, "local": {"EXPID": "a01c", "HPCARCH": "marenostrum4", "PROJECT_PATH": ""}}, "conf": {"mail": {"NOTIFICATIONS": "False", "TO": ""}, "config": {"EXPID": "a01c", "TOTALJOBS": "20", "MAXWAITINGJOBS": "20", "RETRIALS": "0", "AUTOSUBMIT_VERSION": "3.15.0b", "SAFETYSLEEPTIME": "10"}, "wrapper": {"POLICY": "mixed", "JOBS_IN_WRAPPER": "CMORATM&CMOROCE&CMORTM5&CMORLPJG&SAVEIC&POST", "MAX_WRAPPED": "20", "TYPE": "horizontal", "MIN_WRAPPED": "10"}}, "proj": {"lpjg": {"LPJG_FORCING_DIR": "", "LPJG": "TRUE", "LPJG_FIXLUAFTER": "1850", "LPJG_ini_member": "fc2", "LPJG_STATE_DIR": "", "LPJG_FIXNDEPAFTER": "1850", "LPJG_ini_date": "32850101", "LPJG_ini": "a2t4", "LPJG_SAVE_ICMCL": "FALSE", "LPJG_SAVE_RESTART": "TRUE", "LPJG_IFS_OUTPUT_DIR": "", "LPJG_STATE_DIR_INI": "TRUE", "LPJG_CONFIG": "lpjg:fdbck"}, "tm5": {"TM5_ini_date": "", "TM5_ini": "", "TM5": "TRUE", "TM5_ini_member": "", "TM5_ISTART": "9", "TM5_NLEVS": "10", "TM5_EMISS_FIXYEAR": "-1", "TM5_CONFIG": "tm5:co2,co2fb"}, "ECMWF_SYNCHRONIZATION": {"UPDATE_MODEL": "TRUE", "DT_HOST": "", "MODEL_EXTRACT": "TRUE", "DTHOSTMACHINE": "", "DT_USER": ""}, "ifs": {"ATM_ini_member": "fc2", "ATM_SH_LEVELS": "", "ATM_ini": "a2t4", "LHVOLCA": "TRUE", "LCMIP5": "TRUE", "ATM_SH_CODES": "", "LSPPT": "FALSE", "ATM_refnud": "", "ATM_ini_date": "32850101", "SAVEDDA": "FALSE", "SAVEMMA": "FALSE", "ATM_REDUCED_OUTPUT": "TRUE", "NFRP": "6", "ATM_NUDGING": "FALSE", "LWRITE_ARP": "FALSE", "SAVEMMO": "FALSE", "ATM_ini_member_perturb": "FALSE", "ATM_GG_LEVELS": "", "ATM_GG_CODES": "", "CMIP6_SCENARIO": "SSP2-4.5", "IFS_VEG_SOURCE": "cmip6", "NFIXYR": "1850", "CMIP5_RCP": "0"}, "save_ic": {"SAVE_IC": "TRUE", "SAVE_IC_OFFSET": "\"+1 month\" \"+4 month\" \"+ 7 month\" \"+ 10 month\" \"+ 12 month\"", "SAVE_IC_COND": "true", "SAVE_IC_REPOS": "FALSE"}, "nemo": {"NEM_FIXED_FORCING_YEAR": "-1", "OCE_NUDG_DATA": "", "SURF_RESTO_DATA_member": "all_members", "OCE_NUDG_COEFF": "", "OCEAN_ini_date": "32850101", "OCE_NUDG_DATA_member": "", "NEMO_remove_land": "TRUE", "NEM_FORCING_SET": "CoreII", "OCEAN_ini": "a2t4", "OCEAN_STORERST": "FALSE", "OCE_NUDG": "FALSE", "SURF_RESTO_MASK": "DEFAULT", "OCEAN_ini_member": "fc2", "SURF_RESTO_DATA": "s4_surfresto", "SURF_RESTO": "FALSE"}, "transfer": {"USE_DT_COMMANDS": "FALSE"}, "ice": {"ICE_ini": "a2t4", "ICE_ini_date": "32850101", "ICE": "LIM3", "ICE_ini_member": "fc2"}, "oasis": {"OASIS3": "yes", "OASIS_ini": "a2t4", "OASIS_nproc": "", "OASIS_ini_date": "32850101", "OASIS_ini_member": "fc2"}, "grid": {"NEMO_resolution": "ORCA1L75", "IFS_resolution": "T255L91"}, "common": {"CMOR_EXP_CUSTOM": "FALSE", "FORCE_RUN_FROM_SCRATCH": "TRUE", "OSM_NUMPROC": "", "CMORIZATION": "TRUE", "CMOR_ACTIVITY_ID": "CMIP", "TEMPLATE_NAME": "ecearth3", "MODEL": "ecearth", "CMOR_MODEL_ID": "EC-EARTH-CC", "PRODUCTION_EXP": "FALSE", "PRECOMPILED_VERSION": "v3.3.4", "TAPES_GRANULARITY_LEVEL": "diags, plots, original_files/$start_date, original_files/logfiles, original_files/runtime, original_files/cmorfiles/*/*/*/*/*/$MIP_table", "USE_INTERMEDIATE_STORAGE": "FALSE", "DELETE_RUN_DIR_ON_INI": "FALSE", "LPJG_NUMPROC": "8", "USE_MACHINEFILE": "TRUE", "ASSOCIATED_EXPERIMENT": "", "IFS_NUMPROC": "256", "NEM_NUMPROC": "192", "TM5_NUMPROC_Y": "2", "TM5_NUMPROC_X": "2", "DELETE_INI_DIR_ON_INI": "TRUE", "VERSION": "trunk", "SAVE_INIDATA": "FALSE", "XIO_NUMPROC": "2", "BSC_OUTCLASS": "CMIP6/CMIP/EC-EARTH-CC/cmip6-experiment-CMIP-piControl", "SAVE_RESTARTS": "FALSE", "CMOR_REALIZATION_INDEX": "", "CMOR_INITIALIZATION_INDEX": "", "CMOR_EXP": "piControl", "LUCIA": "0", "CMOR_ADD_STARTDATE": "FALSE", "MODEL_RES": "LR", "OSM_THREADS": "", "DEBUG_MODE": "FALSE", "SAVE_RUNTIME": "FALSE", "CMIP6_OUTCLASS": ""}, "diagnostics": {"ECE3_POSTPROC": "FALSE", "DIAG_RECIPES": "LAND", "PROJ_TYPE": "STANDARD", "DIAGS": "BASIC_OCEAN BASIC_SEAICE BASIC_PISCES density sivolume,Northern_Hemisphere:Southern_Hemisphere", "DIAGS_FREQ": "mon", "MONITOR_RECIPES": "OCEAN ATMOS OBGC SEAICE LAND"}, "remote_setup": {"MODEL_CLEAN": "TRUE", "MODEL_EXTRACT": "TRUE"}, "pisces": {"PISCES_ini_member": "fc2", "PISCES_ini": "a2t4", "PISCES_OFF_DYN": "", "PISCES_ini_date": "32850101", "PISCES": "TRUE", "PISCES_OFF": "FALSE"}, "osm": {"OSM_FORCING_TYPE": "erai", "OSM_CONFIG": "osm:post_all", "OSM": "FALSE", "OSM_IFS_OUTPUT_DIR": "", "OSM_FORCING_DIR": "/gpfs/projects/bsc32/bsc32051/OSM_FORCING/${osm_forcing_type}/${ifs_grid}"}}}');
CREATE TABLE job_data (
      id INTEGER NOT NULL PRIMARY KEY AUTOINCREMENT,
      counter INTEGER NOT NULL,
      job_name TEXT NOT NULL,
      created TEXT NOT NULL,
      modified TEXT NOT NULL,
      submit INTEGER NOT NULL,
      start INTEGER NOT NULL,
      finish INTEGER NOT NULL,
      status TEXT NOT NULL,
      rowtype INTEGER NOT NULL,
      ncpus INTEGER NOT NULL,
      wallclock TEXT NOT NULL,
      qos TEXT NOT NULL,
      energy INTEGER NOT NULL,
      date TEXT NOT NULL,
      section TEXT NOT NULL,
      member TEXT NOT NULL,
      chunk INTEGER NOT NULL,
      last INTEGER NOT NULL,
      platform TEXT NOT NULL,
      job_id INTEGER NOT NULL,
      extra_data TEXT NOT NULL,
      nnodes INTEGER NOT NULL DEFAULT 0,
      run_id INTEGER,
      MaxRSS REAL NOT NULL DEFAULT 0.0,
      AveRSS REAL NOT NULL DEFAULT 0.0,
      out TEXT NOT NULL,
      err TEXT NOT NULL,
      rowstatus INTEGER NOT NULL DEFAULT 0,
      children TEXT,
      platform_output TEXT,
      UNIQUE(counter,job_name)
      );
INSERT INTO job_data VALUES(1,0,'a01c_18500101_fc0_1_SIM','2023-09-19-14:51:14','2023-09-19-14:57:24',1695127874,1695127874,1695128103,'FAILED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',1,0,'LOCAL',65944,'',0,1,0.0,0.0,'a01c_18500101_fc0_1_SIM.20230919145126.out','a01c_18500101_fc0_1_SIM.20230919145126.err',5,'a01c_18500101_fc0_1_CMOROCE,a01c_18500101_fc0_1_CMORLPJG,a01c_18500101_fc0_2_SIM,a01c_18500101_fc0_1_CMORTM5,a01c_18500101_fc0_1_SAVEIC','');
INSERT INTO job_data VALUES(2,1,'a01c_18500101_fc0_1_SIM','2023-09-19-14:57:24','2023-09-19-15:00:48',1695128244,1695128244,0,'RUNNING',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',1,0,'LOCAL',67103,'',0,2,0.0,0.0,'','',0,'a01c_18500101_fc0_1_CMOROCE,a01c_18500101_fc0_1_CMORLPJG,a01c_18500101_fc0_2_SIM,a01c_18500101_fc0_1_CMORTM5,a01c_18500101_fc0_1_SAVEIC','');
INSERT INTO job_data VALUES(3,2,'a01c_18500101_fc0_1_SIM','2023-09-19-15:00:48','2023-09-19-15:01:00',1695128448,1695128448,1695128449,'COMPLETED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',1,1,'LOCAL',67554,'',0,4,0.0,0.0,'a01c_18500101_fc0_1_SIM.20230919150100.out','a01c_18500101_fc0_1_SIM.20230919150100.err',5,'a01c_18500101_fc0_1_CMOROCE,a01c_18500101_fc0_1_CMORLPJG,a01c_18500101_fc0_2_SIM,a01c_18500101_fc0_1_CMORTM5,a01c_18500101_fc0_1_SAVEIC','');
INSERT INTO job_data VALUES(4,2,'a01c_18500101_fc0_2_SIM','2023-09-19-15:01:00','2023-09-19-15:01:19',1695128460,1695128460,1695128461,'COMPLETED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',2,1,'LOCAL',67590,'',0,4,0.0,0.0,'a01c_18500101_fc0_2_SIM.20230919150119.out','a01c_18500101_fc0_2_SIM.20230919150119.err',5,'a01c_18500101_fc0_2_CMORLPJG,a01c_18500101_fc0_1_CMORATM,a01c_18500101_fc0_2_CMORTM5,a01c_18500101_fc0_2_SAVEIC,a01c_18500101_fc0_2_CMOROCE,a01c_18500101_fc0_3_SIM','');
INSERT INTO job_data VALUES(5,2,'a01c_18500101_fc0_1_SAVEIC','2023-09-19-15:01:07','2023-09-19-15:02:32',1695128467,1695128472,1695128473,'COMPLETED',2,12,'01:00','bsc_es',312,'1850-01-01 00:00:00','SAVEIC','fc0',1,1,'marenostrum4',30219289,'',1,4,0.0,0.0,'a01c_18500101_fc0_1_SAVEIC.20230919150129.out','a01c_18500101_fc0_1_SAVEIC.20230919150129.err',2,'a01c_18500101_fc0_1_POST',replace('                 30219289  COMPLETED         12        1 2023-09-19T15:01:07 2023-09-19T15:01:08 2023-09-19T15:01:13            312                                                     \n           30219289.batch  COMPLETED         12        1 2023-09-19T15:01:08 2023-09-19T15:01:08 2023-09-19T15:01:13            270                      839K                      839K \n          30219289.extern  COMPLETED         12        1 2023-09-19T15:01:08 2023-09-19T15:01:08 2023-09-19T15:01:13            312                       28K                       28K \n','\n',char(10)));
INSERT INTO job_data VALUES(6,2,'a01c_18500101_fc0_1_CMORLPJG','2023-09-19-15:01:07','2023-09-19-15:02:34',1695128467,1695128469,1695128470,'COMPLETED',2,1,'2:00','bsc_es',349,'1850-01-01 00:00:00','CMORLPJG','fc0',1,1,'marenostrum4',30219290,'',1,4,0.0,0.0,'a01c_18500101_fc0_1_CMORLPJG.20230919150130.out','a01c_18500101_fc0_1_CMORLPJG.20230919150130.err',2,'a01c_18500101_fc0_1_POST',replace('                 30219290  COMPLETED          1        1 2023-09-19T15:01:07 2023-09-19T15:01:08 2023-09-19T15:01:10            349                                                     \n           30219290.batch  COMPLETED          1        1 2023-09-19T15:01:08 2023-09-19T15:01:08 2023-09-19T15:01:10            298                      808K                      808K \n          30219290.extern  COMPLETED          1        1 2023-09-19T15:01:08 2023-09-19T15:01:08 2023-09-19T15:01:10            349                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(7,2,'a01c_18500101_fc0_1_CMORTM5','2023-09-19-15:01:07','2023-09-19-15:02:35',1695128467,1695128469,1695128470,'COMPLETED',2,1,'2:00','bsc_es',348,'1850-01-01 00:00:00','CMORTM5','fc0',1,1,'marenostrum4',30219291,'',1,4,0.0,0.0,'a01c_18500101_fc0_1_CMORTM5.20230919150131.out','a01c_18500101_fc0_1_CMORTM5.20230919150131.err',2,'a01c_18500101_fc0_1_POST',replace('                 30219291  COMPLETED          1        1 2023-09-19T15:01:07 2023-09-19T15:01:08 2023-09-19T15:01:10            348                                                     \n           30219291.batch  COMPLETED          1        1 2023-09-19T15:01:08 2023-09-19T15:01:08 2023-09-19T15:01:10            300                      840K                      840K \n          30219291.extern  COMPLETED          1        1 2023-09-19T15:01:08 2023-09-19T15:01:08 2023-09-19T15:01:10            348                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(8,2,'a01c_18500101_fc0_1_CMOROCE','2023-09-19-15:01:07','2023-09-19-15:02:37',1695128467,1695128469,1695128470,'COMPLETED',2,1,'1:00','bsc_es',348,'1850-01-01 00:00:00','CMOROCE','fc0',1,1,'marenostrum4',30219292,'',1,4,0.0,0.0,'a01c_18500101_fc0_1_CMOROCE.20230919150133.out','a01c_18500101_fc0_1_CMOROCE.20230919150133.err',2,'a01c_18500101_fc0_1_POST',replace('                 30219292  COMPLETED          1        1 2023-09-19T15:01:07 2023-09-19T15:01:08 2023-09-19T15:01:10            348                                                     \n           30219292.batch  COMPLETED          1        1 2023-09-19T15:01:08 2023-09-19T15:01:08 2023-09-19T15:01:10            293                      810K                      810K \n          30219292.extern  COMPLETED          1        1 2023-09-19T15:01:08 2023-09-19T15:01:08 2023-09-19T15:01:10            348                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(9,2,'a01c_18500101_fc0_3_SIM','2023-09-19-15:01:33','2023-09-19-15:01:52',1695128493,1695128493,1695128494,'COMPLETED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',3,1,'LOCAL',67659,'',0,4,0.0,0.0,'a01c_18500101_fc0_3_SIM.20230919150152.out','a01c_18500101_fc0_3_SIM.20230919150152.err',5,'a01c_18500101_fc0_2_CMORATM,a01c_18500101_fc0_4_SIM,a01c_18500101_fc0_3_CMORLPJG,a01c_18500101_fc0_3_CMORTM5,a01c_18500101_fc0_3_SAVEIC,a01c_18500101_fc0_3_CMOROCE','');
INSERT INTO job_data VALUES(10,2,'a01c_18500101_fc0_2_SAVEIC','2023-09-19-15:01:40','2023-09-19-15:03:05',1695128500,1695128505,1695128506,'COMPLETED',2,12,'01:00','bsc_es',289,'1850-01-01 00:00:00','SAVEIC','fc0',2,1,'marenostrum4',30219296,'',1,4,0.0,0.0,'a01c_18500101_fc0_2_SAVEIC.20230919150201.out','a01c_18500101_fc0_2_SAVEIC.20230919150201.err',2,'a01c_18500101_fc0_2_POST',replace('                 30219296  COMPLETED         12        1 2023-09-19T15:01:40 2023-09-19T15:01:41 2023-09-19T15:01:46            289                                                     \n           30219296.batch  COMPLETED         12        1 2023-09-19T15:01:41 2023-09-19T15:01:41 2023-09-19T15:01:46            255                      837K                      837K \n          30219296.extern  COMPLETED         12        1 2023-09-19T15:01:41 2023-09-19T15:01:41 2023-09-19T15:01:46            289                       24K                       24K \n','\n',char(10)));
INSERT INTO job_data VALUES(11,2,'a01c_18500101_fc0_2_CMORLPJG','2023-09-19-15:01:40','2023-09-19-15:03:07',1695128500,1695128502,1695128503,'COMPLETED',2,1,'2:00','bsc_es',346,'1850-01-01 00:00:00','CMORLPJG','fc0',2,1,'marenostrum4',30219297,'',1,4,0.0,0.0,'a01c_18500101_fc0_2_CMORLPJG.20230919150202.out','a01c_18500101_fc0_2_CMORLPJG.20230919150202.err',2,'a01c_18500101_fc0_2_POST',replace('                 30219297  COMPLETED          1        1 2023-09-19T15:01:40 2023-09-19T15:01:41 2023-09-19T15:01:43            346                                                     \n           30219297.batch  COMPLETED          1        1 2023-09-19T15:01:41 2023-09-19T15:01:41 2023-09-19T15:01:43            295                      810K                      810K \n          30219297.extern  COMPLETED          1        1 2023-09-19T15:01:41 2023-09-19T15:01:41 2023-09-19T15:01:43            346                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(12,2,'a01c_18500101_fc0_2_CMORTM5','2023-09-19-15:01:40','2023-09-19-15:03:08',1695128500,1695128502,1695128503,'COMPLETED',2,1,'2:00','bsc_es',345,'1850-01-01 00:00:00','CMORTM5','fc0',2,1,'marenostrum4',30219298,'',1,4,0.0,0.0,'a01c_18500101_fc0_2_CMORTM5.20230919150204.out','a01c_18500101_fc0_2_CMORTM5.20230919150204.err',2,'a01c_18500101_fc0_2_POST',replace('                 30219298  COMPLETED          1        1 2023-09-19T15:01:40 2023-09-19T15:01:41 2023-09-19T15:01:43            345                                                     \n           30219298.batch  COMPLETED          1        1 2023-09-19T15:01:41 2023-09-19T15:01:41 2023-09-19T15:01:43            280                      814K                      814K \n          30219298.extern  COMPLETED          1        1 2023-09-19T15:01:41 2023-09-19T15:01:41 2023-09-19T15:01:43            345                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(13,2,'a01c_18500101_fc0_1_CMORATM','2023-09-19-15:01:40','2023-09-19-15:03:10',1695128500,1695128502,1695128503,'COMPLETED',2,1,'2:00','bsc_es',345,'1850-01-01 00:00:00','CMORATM','fc0',1,1,'marenostrum4',30219299,'',1,4,0.0,0.0,'a01c_18500101_fc0_1_CMORATM.20230919150206.out','a01c_18500101_fc0_1_CMORATM.20230919150206.err',2,'a01c_18500101_fc0_1_POST',replace('                 30219299  COMPLETED          1        1 2023-09-19T15:01:40 2023-09-19T15:01:41 2023-09-19T15:01:43            345                                                     \n           30219299.batch  COMPLETED          1        1 2023-09-19T15:01:41 2023-09-19T15:01:41 2023-09-19T15:01:43            290                      816K                      816K \n          30219299.extern  COMPLETED          1        1 2023-09-19T15:01:41 2023-09-19T15:01:41 2023-09-19T15:01:43            345                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(14,2,'a01c_18500101_fc0_2_CMOROCE','2023-09-19-15:01:40','2023-09-19-15:03:11',1695128500,1695128502,1695128503,'COMPLETED',2,1,'1:00','bsc_es',346,'1850-01-01 00:00:00','CMOROCE','fc0',2,1,'marenostrum4',30219300,'',1,4,0.0,0.0,'a01c_18500101_fc0_2_CMOROCE.20230919150207.out','a01c_18500101_fc0_2_CMOROCE.20230919150207.err',2,'a01c_18500101_fc0_2_POST',replace('                 30219300  COMPLETED          1        1 2023-09-19T15:01:40 2023-09-19T15:01:41 2023-09-19T15:01:43            346                                                     \n           30219300.batch  COMPLETED          1        1 2023-09-19T15:01:41 2023-09-19T15:01:41 2023-09-19T15:01:43            285                      812K                      812K \n          30219300.extern  COMPLETED          1        1 2023-09-19T15:01:41 2023-09-19T15:01:41 2023-09-19T15:01:43            346                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(15,2,'a01c_18500101_fc0_4_SIM','2023-09-19-15:02:08','2023-09-19-15:03:52',1695128528,1695128528,1695128529,'COMPLETED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',4,1,'LOCAL',67738,'',0,4,0.0,0.0,'a01c_18500101_fc0_4_SIM.20230919150352.out','a01c_18500101_fc0_4_SIM.20230919150352.err',5,'a01c_18500101_fc0_4_CMORTM5,a01c_18500101_fc0_4_CMORLPJG,a01c_18500101_fc0_4_SAVEIC,a01c_18500101_fc0_3_CMORATM,a01c_18500101_fc0_5_SIM,a01c_18500101_fc0_4_CMOROCE','');
INSERT INTO job_data VALUES(16,2,'a01c_18500101_fc0_5_SIM','2023-09-19-15:03:52','2023-09-19-15:04:17',1695128632,1695128632,1695128633,'COMPLETED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',5,1,'LOCAL',67911,'',0,4,0.0,0.0,'a01c_18500101_fc0_5_SIM.20230919150417.out','a01c_18500101_fc0_5_SIM.20230919150417.err',5,'a01c_18500101_fc0_5_CMORLPJG,a01c_18500101_fc0_5_CMORTM5,a01c_18500101_fc0_5_SAVEIC,a01c_18500101_fc0_6_SIM,a01c_18500101_fc0_5_CMOROCE,a01c_18500101_fc0_4_CMORATM','');
INSERT INTO job_data VALUES(17,2,'a01c_18500101_fc0_3_SAVEIC','2023-09-19-15:04:05','2023-09-19-15:05:39',1695128645,1695128658,1695128659,'COMPLETED',2,12,'01:00','bsc_es',318,'1850-01-01 00:00:00','SAVEIC','fc0',3,1,'marenostrum4',30219306,'',1,4,0.0,0.0,'a01c_18500101_fc0_3_SAVEIC.20230919150434.out','a01c_18500101_fc0_3_SAVEIC.20230919150434.err',2,'a01c_18500101_fc0_3_POST',replace('                 30219306  COMPLETED         12        1 2023-09-19T15:04:05 2023-09-19T15:04:15 2023-09-19T15:04:20            318                                                     \n           30219306.batch  COMPLETED         12        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:20            257                      837K                      837K \n          30219306.extern  COMPLETED         12        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:20            318                       24K                       24K \n','\n',char(10)));
INSERT INTO job_data VALUES(18,2,'a01c_18500101_fc0_4_SAVEIC','2023-09-19-15:04:05','2023-09-19-15:05:40',1695128645,1695128657,1695128658,'COMPLETED',2,12,'01:00','bsc_es',563,'1850-01-01 00:00:00','SAVEIC','fc0',4,1,'marenostrum4',30219307,'',1,4,0.0,0.0,'a01c_18500101_fc0_4_SAVEIC.20230919150434.out','a01c_18500101_fc0_4_SAVEIC.20230919150434.err',2,'a01c_18500101_fc0_4_POST',replace('                 30219307  COMPLETED         12        1 2023-09-19T15:04:05 2023-09-19T15:04:15 2023-09-19T15:04:20            563                                                     \n           30219307.batch  COMPLETED         12        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:20            287                      931K                      931K \n          30219307.extern  COMPLETED         12        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:20            563                       22K                       22K \n','\n',char(10)));
INSERT INTO job_data VALUES(19,2,'a01c_18500101_fc0_3_CMORLPJG','2023-09-19-15:04:05','2023-09-19-15:05:37',1695128645,1695128655,1695128656,'COMPLETED',2,1,'2:00','bsc_es',507,'1850-01-01 00:00:00','CMORLPJG','fc0',3,1,'marenostrum4',30219308,'',1,4,0.0,0.0,'a01c_18500101_fc0_3_CMORLPJG.20230919150431.out','a01c_18500101_fc0_3_CMORLPJG.20230919150431.err',2,'a01c_18500101_fc0_3_POST',replace('                 30219308  COMPLETED          1        1 2023-09-19T15:04:05 2023-09-19T15:04:15 2023-09-19T15:04:17            507                                                     \n           30219308.batch  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            289                      836K                      836K \n          30219308.extern  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            507                       68K                       68K \n','\n',char(10)));
INSERT INTO job_data VALUES(20,2,'a01c_18500101_fc0_4_CMORLPJG','2023-09-19-15:04:05','2023-09-19-15:05:38',1695128645,1695128655,1695128656,'COMPLETED',2,1,'2:00','bsc_es',507,'1850-01-01 00:00:00','CMORLPJG','fc0',4,1,'marenostrum4',30219309,'',1,4,0.0,0.0,'a01c_18500101_fc0_4_CMORLPJG.20230919150432.out','a01c_18500101_fc0_4_CMORLPJG.20230919150432.err',2,'a01c_18500101_fc0_4_POST',replace('                 30219309  COMPLETED          1        1 2023-09-19T15:04:05 2023-09-19T15:04:15 2023-09-19T15:04:17            507                                                     \n           30219309.batch  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            284                      812K                      812K \n          30219309.extern  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            507                       68K                       68K \n','\n',char(10)));
INSERT INTO job_data VALUES(21,2,'a01c_18500101_fc0_3_CMORTM5','2023-09-19-15:04:05','2023-09-19-15:05:32',1695128645,1695128656,1695128657,'COMPLETED',2,1,'2:00','bsc_es',540,'1850-01-01 00:00:00','CMORTM5','fc0',3,1,'marenostrum4',30219310,'',1,4,0.0,0.0,'a01c_18500101_fc0_3_CMORTM5.20230919150428.out','a01c_18500101_fc0_3_CMORTM5.20230919150428.err',2,'a01c_18500101_fc0_3_POST',replace('                 30219310  COMPLETED          1        1 2023-09-19T15:04:05 2023-09-19T15:04:15 2023-09-19T15:04:17            540                                                     \n           30219310.batch  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            263                      816K                      816K \n          30219310.extern  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            540                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(22,2,'a01c_18500101_fc0_4_CMORTM5','2023-09-19-15:04:05','2023-09-19-15:05:31',1695128645,1695128656,1695128657,'COMPLETED',2,1,'2:00','bsc_es',542,'1850-01-01 00:00:00','CMORTM5','fc0',4,1,'marenostrum4',30219311,'',1,4,0.0,0.0,'a01c_18500101_fc0_4_CMORTM5.20230919150427.out','a01c_18500101_fc0_4_CMORTM5.20230919150427.err',2,'a01c_18500101_fc0_4_POST',replace('                 30219311  COMPLETED          1        1 2023-09-19T15:04:05 2023-09-19T15:04:15 2023-09-19T15:04:17            542                                                     \n           30219311.batch  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            261                      814K                      814K \n          30219311.extern  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            542                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(23,2,'a01c_18500101_fc0_2_CMORATM','2023-09-19-15:04:05','2023-09-19-15:05:35',1695128645,1695128656,1695128657,'COMPLETED',2,1,'2:00','bsc_es',541,'1850-01-01 00:00:00','CMORATM','fc0',2,1,'marenostrum4',30219312,'',1,4,0.0,0.0,'a01c_18500101_fc0_2_CMORATM.20230919150429.out','a01c_18500101_fc0_2_CMORATM.20230919150429.err',2,'a01c_18500101_fc0_1_POST',replace('                 30219312  COMPLETED          1        1 2023-09-19T15:04:05 2023-09-19T15:04:15 2023-09-19T15:04:17            541                                                     \n           30219312.batch  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            262                      812K                      812K \n          30219312.extern  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            541                      702K                      702K \n','\n',char(10)));
INSERT INTO job_data VALUES(24,2,'a01c_18500101_fc0_3_CMORATM','2023-09-19-15:04:05','2023-09-19-15:05:34',1695128645,1695128655,1695128656,'COMPLETED',2,1,'2:00','bsc_es',501,'1850-01-01 00:00:00','CMORATM','fc0',3,1,'marenostrum4',30219313,'',1,4,0.0,0.0,'a01c_18500101_fc0_3_CMORATM.20230919150429.out','a01c_18500101_fc0_3_CMORATM.20230919150429.err',2,'a01c_18500101_fc0_2_POST',replace('                 30219313  COMPLETED          1        1 2023-09-19T15:04:05 2023-09-19T15:04:15 2023-09-19T15:04:17            501                                                     \n           30219313.batch  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            268                      812K                      812K \n          30219313.extern  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            501                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(25,2,'a01c_18500101_fc0_3_CMOROCE','2023-09-19-15:04:05','2023-09-19-15:05:36',1695128645,1695128655,1695128656,'COMPLETED',2,1,'1:00','bsc_es',496,'1850-01-01 00:00:00','CMOROCE','fc0',3,1,'marenostrum4',30219314,'',1,4,0.0,0.0,'a01c_18500101_fc0_3_CMOROCE.20230919150430.out','a01c_18500101_fc0_3_CMOROCE.20230919150430.err',2,'a01c_18500101_fc0_3_POST',replace('                 30219314  COMPLETED          1        1 2023-09-19T15:04:05 2023-09-19T15:04:15 2023-09-19T15:04:17            496                                                     \n           30219314.batch  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            273                      816K                      816K \n          30219314.extern  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            496                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(26,2,'a01c_18500101_fc0_4_CMOROCE','2023-09-19-15:04:05','2023-09-19-15:05:35',1695128645,1695128655,1695128656,'COMPLETED',2,1,'1:00','bsc_es',505,'1850-01-01 00:00:00','CMOROCE','fc0',4,1,'marenostrum4',30219315,'',1,4,0.0,0.0,'a01c_18500101_fc0_4_CMOROCE.20230919150430.out','a01c_18500101_fc0_4_CMOROCE.20230919150430.err',2,'a01c_18500101_fc0_4_POST',replace('                 30219315  COMPLETED          1        1 2023-09-19T15:04:05 2023-09-19T15:04:15 2023-09-19T15:04:17            505                                                     \n           30219315.batch  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            280                      814K                      814K \n          30219315.extern  COMPLETED          1        1 2023-09-19T15:04:15 2023-09-19T15:04:15 2023-09-19T15:04:17            505                      710K                      710K \n','\n',char(10)));
INSERT INTO job_data VALUES(27,2,'a01c_18500101_fc0_6_SIM','2023-09-19-15:04:36','2023-09-19-15:04:55',1695128676,1695128676,1695128677,'COMPLETED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',6,1,'LOCAL',68040,'',0,4,0.0,0.0,'a01c_18500101_fc0_6_SIM.20230919150455.out','a01c_18500101_fc0_6_SIM.20230919150455.err',5,'a01c_18500101_fc0_6_CMOROCE,a01c_18500101_fc0_5_CMORATM,a01c_18500101_fc0_7_SIM,a01c_18500101_fc0_6_SAVEIC,a01c_18500101_fc0_6_CMORTM5,a01c_18500101_fc0_6_CMORLPJG','');
INSERT INTO job_data VALUES(28,2,'a01c_18500101_fc0_4_CMORATM','2023-09-19-15:04:42','2023-09-19-15:06:12',1695128682,1695128685,1695128686,'COMPLETED',2,1,'2:00','bsc_es',498,'1850-01-01 00:00:00','CMORATM','fc0',4,1,'marenostrum4',30219317,'',1,4,0.0,0.0,'a01c_18500101_fc0_4_CMORATM.20230919150508.out','a01c_18500101_fc0_4_CMORATM.20230919150508.err',2,'a01c_18500101_fc0_3_POST',replace('                 30219317  COMPLETED          1        1 2023-09-19T15:04:42 2023-09-19T15:04:45 2023-09-19T15:04:47            498                                                     \n           30219317.batch  COMPLETED          1        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:47            279                      812K                      812K \n          30219317.extern  COMPLETED          1        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:47            498                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(29,2,'a01c_18500101_fc0_5_CMOROCE','2023-09-19-15:04:42','2023-09-19-15:06:17',1695128682,1695128685,1695128686,'COMPLETED',2,1,'1:00','bsc_es',492,'1850-01-01 00:00:00','CMOROCE','fc0',5,1,'marenostrum4',30219318,'',1,4,0.0,0.0,'a01c_18500101_fc0_5_CMOROCE.20230919150513.out','a01c_18500101_fc0_5_CMOROCE.20230919150513.err',2,'a01c_18500101_fc0_5_POST',replace('                 30219318  COMPLETED          1        1 2023-09-19T15:04:42 2023-09-19T15:04:45 2023-09-19T15:04:47            492                                                     \n           30219318.batch  COMPLETED          1        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:47            273                      814K                      814K \n          30219318.extern  COMPLETED          1        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:47            492                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(30,2,'a01c_18500101_fc0_5_CMORLPJG','2023-09-19-15:04:42','2023-09-19-15:06:15',1695128682,1695128685,1695128686,'COMPLETED',2,1,'2:00','bsc_es',497,'1850-01-01 00:00:00','CMORLPJG','fc0',5,1,'marenostrum4',30219319,'',1,4,0.0,0.0,'a01c_18500101_fc0_5_CMORLPJG.20230919150512.out','a01c_18500101_fc0_5_CMORLPJG.20230919150512.err',2,'a01c_18500101_fc0_5_POST',replace('                 30219319  COMPLETED          1        1 2023-09-19T15:04:42 2023-09-19T15:04:45 2023-09-19T15:04:47            497                                                     \n           30219319.batch  COMPLETED          1        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:47            270                      812K                      812K \n          30219319.extern  COMPLETED          1        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:47            497                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(31,2,'a01c_18500101_fc0_5_CMORTM5','2023-09-19-15:04:42','2023-09-19-15:06:10',1695128682,1695128685,1695128686,'COMPLETED',2,1,'2:00','bsc_es',498,'1850-01-01 00:00:00','CMORTM5','fc0',5,1,'marenostrum4',30219320,'',1,4,0.0,0.0,'a01c_18500101_fc0_5_CMORTM5.20230919150505.out','a01c_18500101_fc0_5_CMORTM5.20230919150505.err',2,'a01c_18500101_fc0_5_POST',replace('                 30219320  COMPLETED          1        1 2023-09-19T15:04:42 2023-09-19T15:04:45 2023-09-19T15:04:47            498                                                     \n           30219320.batch  COMPLETED          1        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:47            263                      814K                      814K \n          30219320.extern  COMPLETED          1        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:47            498                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(32,2,'a01c_18500101_fc0_5_SAVEIC','2023-09-19-15:04:42','2023-09-19-15:06:14',1695128682,1695128688,1695128689,'COMPLETED',2,12,'01:00','bsc_es',287,'1850-01-01 00:00:00','SAVEIC','fc0',5,1,'marenostrum4',30219321,'',1,4,0.0,0.0,'a01c_18500101_fc0_5_SAVEIC.20230919150510.out','a01c_18500101_fc0_5_SAVEIC.20230919150510.err',2,'a01c_18500101_fc0_5_POST',replace('                 30219321  COMPLETED         12        1 2023-09-19T15:04:42 2023-09-19T15:04:45 2023-09-19T15:04:49            287                                                     \n           30219321.batch  COMPLETED         12        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:49            253                      838K                      838K \n          30219321.extern  COMPLETED         12        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:49            287                       20K                       20K \n','\n',char(10)));
INSERT INTO job_data VALUES(33,2,'a01c_18500101_fc0_1_POST','2023-09-19-15:04:42','2023-09-19-15:06:18',1695128682,1695128687,1695128688,'COMPLETED',2,12,'01:00','bsc_es',306,'1850-01-01 00:00:00','POST','fc0',1,1,'marenostrum4',30219322,'',1,4,0.0,0.0,'a01c_18500101_fc0_1_POST.20230919150515.out','a01c_18500101_fc0_1_POST.20230919150515.err',2,'a01c_18500101_fc0_2_POST,a01c_18500101_fc0_1_CLEAN',replace('                 30219322  COMPLETED         12        1 2023-09-19T15:04:42 2023-09-19T15:04:45 2023-09-19T15:04:49            306                                                     \n           30219322.batch  COMPLETED         12        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:49            256                      932K                      932K \n          30219322.extern  COMPLETED         12        1 2023-09-19T15:04:45 2023-09-19T15:04:45 2023-09-19T15:04:49            306                       26K                       26K \n','\n',char(10)));
INSERT INTO job_data VALUES(34,2,'a01c_18500101_fc0_7_SIM','2023-09-19-15:05:15','2023-09-19-15:05:36',1695128715,1695128715,1695128716,'COMPLETED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',7,1,'LOCAL',68177,'',0,4,0.0,0.0,'a01c_18500101_fc0_7_SIM.20230919150536.out','a01c_18500101_fc0_7_SIM.20230919150536.err',5,'a01c_18500101_fc0_7_CMOROCE,a01c_18500101_fc0_7_CMORLPJG,a01c_18500101_fc0_7_SAVEIC,a01c_18500101_fc0_7_CMORTM5,a01c_18500101_fc0_6_CMORATM,a01c_18500101_fc0_8_SIM','');
INSERT INTO job_data VALUES(35,2,'a01c_18500101_fc0_5_CMORATM','2023-09-19-15:05:24','2023-09-19-15:06:58',1695128724,1695128727,1695128728,'COMPLETED',2,1,'2:00','bsc_es',338,'1850-01-01 00:00:00','CMORATM','fc0',5,1,'marenostrum4',30219325,'',1,4,0.0,0.0,'a01c_18500101_fc0_5_CMORATM.20230919150555.out','a01c_18500101_fc0_5_CMORATM.20230919150555.err',2,'a01c_18500101_fc0_4_POST',replace('                 30219325  COMPLETED          1        1 2023-09-19T15:05:23 2023-09-19T15:05:27 2023-09-19T15:05:29            338                                                     \n           30219325.batch  COMPLETED          1        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:29            289                      814K                      814K \n          30219325.extern  COMPLETED          1        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:29            338                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(36,2,'a01c_18500101_fc0_6_CMOROCE','2023-09-19-15:05:24','2023-09-19-15:07:00',1695128724,1695128727,1695128728,'COMPLETED',2,1,'1:00','bsc_es',338,'1850-01-01 00:00:00','CMOROCE','fc0',6,1,'marenostrum4',30219326,'',1,4,0.0,0.0,'a01c_18500101_fc0_6_CMOROCE.20230919150557.out','a01c_18500101_fc0_6_CMOROCE.20230919150557.err',2,'a01c_18500101_fc0_6_POST',replace('                 30219326  COMPLETED          1        1 2023-09-19T15:05:23 2023-09-19T15:05:27 2023-09-19T15:05:29            338                                                     \n           30219326.batch  COMPLETED          1        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:29            290                      869K                      869K \n          30219326.extern  COMPLETED          1        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:29            338                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(37,2,'a01c_18500101_fc0_6_CMORLPJG','2023-09-19-15:05:24','2023-09-19-15:07:04',1695128724,1695128727,1695128728,'COMPLETED',2,1,'2:00','bsc_es',317,'1850-01-01 00:00:00','CMORLPJG','fc0',6,1,'marenostrum4',30219327,'',1,4,0.0,0.0,'a01c_18500101_fc0_6_CMORLPJG.20230919150600.out','a01c_18500101_fc0_6_CMORLPJG.20230919150600.err',2,'a01c_18500101_fc0_6_POST',replace('                 30219327  COMPLETED          1        1 2023-09-19T15:05:23 2023-09-19T15:05:27 2023-09-19T15:05:28            317                                                     \n           30219327.batch  COMPLETED          1        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:28            278                      843K                      843K \n          30219327.extern  COMPLETED          1        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:28            317                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(38,2,'a01c_18500101_fc0_6_CMORTM5','2023-09-19-15:05:24','2023-09-19-15:06:54',1695128724,1695128727,1695128728,'COMPLETED',2,1,'2:00','bsc_es',314,'1850-01-01 00:00:00','CMORTM5','fc0',6,1,'marenostrum4',30219328,'',1,4,0.0,0.0,'a01c_18500101_fc0_6_CMORTM5.20230919150551.out','a01c_18500101_fc0_6_CMORTM5.20230919150551.err',2,'a01c_18500101_fc0_6_POST',replace('                 30219328  COMPLETED          1        1 2023-09-19T15:05:23 2023-09-19T15:05:27 2023-09-19T15:05:28            314                                                     \n           30219328.batch  COMPLETED          1        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:28            272                      814K                      814K \n          30219328.extern  COMPLETED          1        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:28            314                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(39,2,'a01c_18500101_fc0_1_CLEAN','2023-09-19-15:05:24','2023-09-19-15:05:24',1695128724,0,0,'SUBMITTED',2,1,'00:30','bsc_es',0,'1850-01-01 00:00:00','CLEAN','fc0',1,1,'marenostrum4',30219329,'',0,4,0.0,0.0,'','',0,'a01c_18500101_fc0_1_EARTHDIAGS,a01c_18500101_fc0_2_CLEAN,a01c_18500101_fc0_11_SIM,a01c_18500101_fc0_5_CLEAN,a01c_18500101_fc0_1_ESMVALTOOL,a01c_18500101_fc0_4_CLEAN,a01c_18500101_fc0_7_CLEAN,a01c_18500101_fc0_6_CLEAN,a01c_18500101_fc0_3_CLEAN,a01c_18500101_fc0_8_CLEAN','');
INSERT INTO job_data VALUES(40,2,'a01c_18500101_fc0_6_SAVEIC','2023-09-19-15:05:24','2023-09-19-15:06:57',1695128724,1695128729,1695128730,'COMPLETED',2,12,'01:00','bsc_es',310,'1850-01-01 00:00:00','SAVEIC','fc0',6,1,'marenostrum4',30219330,'',1,4,0.0,0.0,'a01c_18500101_fc0_6_SAVEIC.20230919150554.out','a01c_18500101_fc0_6_SAVEIC.20230919150554.err',2,'a01c_18500101_fc0_6_POST',replace('                 30219330  COMPLETED         12        1 2023-09-19T15:05:24 2023-09-19T15:05:27 2023-09-19T15:05:31            310                                                     \n           30219330.batch  COMPLETED         12        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:31            258                      899K                      899K \n          30219330.extern  COMPLETED         12        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:31            310                       33K                       33K \n','\n',char(10)));
INSERT INTO job_data VALUES(41,2,'a01c_18500101_fc0_2_POST','2023-09-19-15:05:24','2023-09-19-15:06:55',1695128724,1695128730,1695128731,'COMPLETED',2,12,'01:00','bsc_es',298,'1850-01-01 00:00:00','POST','fc0',2,1,'marenostrum4',30219331,'',1,4,0.0,0.0,'a01c_18500101_fc0_2_POST.20230919150552.out','a01c_18500101_fc0_2_POST.20230919150552.err',2,'a01c_18500101_fc0_2_CLEAN,a01c_18500101_fc0_3_POST',replace('                 30219331  COMPLETED         12        1 2023-09-19T15:05:24 2023-09-19T15:05:27 2023-09-19T15:05:32            298                                                     \n           30219331.batch  COMPLETED         12        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:32            250                      845K                      845K \n          30219331.extern  COMPLETED         12        1 2023-09-19T15:05:27 2023-09-19T15:05:27 2023-09-19T15:05:32            298                       24K                       24K \n','\n',char(10)));
INSERT INTO job_data VALUES(42,2,'a01c_18500101_fc0_8_SIM','2023-09-19-15:06:01','2023-09-19-15:06:22',1695128761,1695128761,1695128762,'COMPLETED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',8,1,'LOCAL',68281,'',0,4,0.0,0.0,'a01c_18500101_fc0_8_SIM.20230919150622.out','a01c_18500101_fc0_8_SIM.20230919150622.err',5,'a01c_18500101_fc0_8_CMORTM5,a01c_18500101_fc0_9_SIM,a01c_18500101_fc0_8_SAVEIC,a01c_18500101_fc0_8_CMORLPJG,a01c_18500101_fc0_7_CMORATM,a01c_18500101_fc0_8_CMOROCE','');
INSERT INTO job_data VALUES(43,2,'a01c_18500101_fc0_6_CMORATM','2023-09-19-15:06:10','2023-09-19-15:07:41',1695128770,1695128775,1695128776,'COMPLETED',2,1,'2:00','bsc_es',495,'1850-01-01 00:00:00','CMORATM','fc0',6,1,'marenostrum4',30219333,'',1,4,0.0,0.0,'a01c_18500101_fc0_6_CMORATM.20230919150637.out','a01c_18500101_fc0_6_CMORATM.20230919150637.err',2,'a01c_18500101_fc0_5_POST',replace('                 30219333  COMPLETED          1        1 2023-09-19T15:06:10 2023-09-19T15:06:15 2023-09-19T15:06:17            495                                                     \n           30219333.batch  COMPLETED          1        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:17            263                      812K                      812K \n          30219333.extern  COMPLETED          1        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:17            495                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(44,2,'a01c_18500101_fc0_7_CMOROCE','2023-09-19-15:06:10','2023-09-19-15:07:48',1695128770,1695128775,1695128776,'COMPLETED',2,1,'1:00','bsc_es',494,'1850-01-01 00:00:00','CMOROCE','fc0',7,1,'marenostrum4',30219334,'',1,4,0.0,0.0,'a01c_18500101_fc0_7_CMOROCE.20230919150644.out','a01c_18500101_fc0_7_CMOROCE.20230919150644.err',2,'a01c_18500101_fc0_7_POST',replace('                 30219334  COMPLETED          1        1 2023-09-19T15:06:10 2023-09-19T15:06:15 2023-09-19T15:06:17            494                                                     \n           30219334.batch  COMPLETED          1        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:17            260                      816K                      816K \n          30219334.extern  COMPLETED          1        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:17            494                      710K                      710K \n','\n',char(10)));
INSERT INTO job_data VALUES(45,2,'a01c_18500101_fc0_7_CMORLPJG','2023-09-19-15:06:10','2023-09-19-15:07:45',1695128770,1695128775,1695128776,'COMPLETED',2,1,'2:00','bsc_es',494,'1850-01-01 00:00:00','CMORLPJG','fc0',7,1,'marenostrum4',30219335,'',1,4,0.0,0.0,'a01c_18500101_fc0_7_CMORLPJG.20230919150641.out','a01c_18500101_fc0_7_CMORLPJG.20230919150641.err',2,'a01c_18500101_fc0_7_POST',replace('                 30219335  COMPLETED          1        1 2023-09-19T15:06:10 2023-09-19T15:06:15 2023-09-19T15:06:17            494                                                     \n           30219335.batch  COMPLETED          1        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:17            254                      814K                      814K \n          30219335.extern  COMPLETED          1        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:17            494                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(46,2,'a01c_18500101_fc0_7_CMORTM5','2023-09-19-15:06:10','2023-09-19-15:07:44',1695128770,1695128775,1695128776,'COMPLETED',2,1,'2:00','bsc_es',494,'1850-01-01 00:00:00','CMORTM5','fc0',7,1,'marenostrum4',30219336,'',1,4,0.0,0.0,'a01c_18500101_fc0_7_CMORTM5.20230919150640.out','a01c_18500101_fc0_7_CMORTM5.20230919150640.err',2,'a01c_18500101_fc0_7_POST',replace('                 30219336  COMPLETED          1        1 2023-09-19T15:06:10 2023-09-19T15:06:15 2023-09-19T15:06:17            494                                                     \n           30219336.batch  COMPLETED          1        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:17            255                      814K                      814K \n          30219336.extern  COMPLETED          1        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:17            494                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(47,2,'a01c_18500101_fc0_7_SAVEIC','2023-09-19-15:06:10','2023-09-19-15:07:42',1695128770,1695128778,1695128779,'COMPLETED',2,12,'01:00','bsc_es',435,'1850-01-01 00:00:00','SAVEIC','fc0',7,1,'marenostrum4',30219337,'',1,4,0.0,0.0,'a01c_18500101_fc0_7_SAVEIC.20230919150639.out','a01c_18500101_fc0_7_SAVEIC.20230919150639.err',2,'a01c_18500101_fc0_7_POST',replace('                 30219337  COMPLETED         12        1 2023-09-19T15:06:10 2023-09-19T15:06:15 2023-09-19T15:06:20            435                                                     \n           30219337.batch  COMPLETED         12        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:20            257                      838K                      838K \n          30219337.extern  COMPLETED         12        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:22            435                       24K                       24K \n','\n',char(10)));
INSERT INTO job_data VALUES(48,2,'a01c_18500101_fc0_3_POST','2023-09-19-15:06:10','2023-09-19-15:07:39',1695128770,1695128777,1695128778,'COMPLETED',2,12,'01:00','bsc_es',681,'1850-01-01 00:00:00','POST','fc0',3,1,'marenostrum4',30219338,'',1,4,0.0,0.0,'a01c_18500101_fc0_3_POST.20230919150636.out','a01c_18500101_fc0_3_POST.20230919150636.err',2,'a01c_18500101_fc0_4_POST,a01c_18500101_fc0_3_CLEAN',replace('                 30219338  COMPLETED         12        1 2023-09-19T15:06:10 2023-09-19T15:06:15 2023-09-19T15:06:20            681                                                     \n           30219338.batch  COMPLETED         12        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:20            286                      932K                      932K \n          30219338.extern  COMPLETED         12        1 2023-09-19T15:06:15 2023-09-19T15:06:15 2023-09-19T15:06:22            681                       30K                       30K \n','\n',char(10)));
INSERT INTO job_data VALUES(49,2,'a01c_18500101_fc0_9_SIM','2023-09-19-15:06:45','2023-09-19-15:07:05',1695128805,1695128805,1695128806,'COMPLETED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',9,1,'LOCAL',68381,'',0,4,0.0,0.0,'a01c_18500101_fc0_9_SIM.20230919150705.out','a01c_18500101_fc0_9_SIM.20230919150705.err',5,'a01c_18500101_fc0_9_CMORLPJG,a01c_18500101_fc0_8_CMORATM,a01c_18500101_fc0_9_SAVEIC,a01c_18500101_fc0_9_CMOROCE,a01c_18500101_fc0_10_SIM,a01c_18500101_fc0_9_CMORTM5','');
INSERT INTO job_data VALUES(50,2,'a01c_18500101_fc0_7_CMORATM','2023-09-19-15:06:53','2023-09-19-15:08:23',1695128813,1695128814,1695128815,'COMPLETED',2,1,'2:00','bsc_es',325,'1850-01-01 00:00:00','CMORATM','fc0',7,1,'marenostrum4',30219340,'',1,4,0.0,0.0,'a01c_18500101_fc0_7_CMORATM.20230919150720.out','a01c_18500101_fc0_7_CMORATM.20230919150720.err',2,'a01c_18500101_fc0_6_POST',replace('                 30219340  COMPLETED          1        1 2023-09-19T15:06:53 2023-09-19T15:06:54 2023-09-19T15:06:55            325                                                     \n           30219340.batch  COMPLETED          1        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:55            279                      837K                      837K \n          30219340.extern  COMPLETED          1        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:55            325                      704K                      704K \n','\n',char(10)));
INSERT INTO job_data VALUES(51,2,'a01c_18500101_fc0_8_CMOROCE','2023-09-19-15:06:53','2023-09-19-15:08:25',1695128813,1695128814,1695128815,'COMPLETED',2,1,'1:00','bsc_es',325,'1850-01-01 00:00:00','CMOROCE','fc0',8,1,'marenostrum4',30219341,'',1,4,0.0,0.0,'a01c_18500101_fc0_8_CMOROCE.20230919150721.out','a01c_18500101_fc0_8_CMOROCE.20230919150721.err',2,'a01c_18500101_fc0_8_POST',replace('                 30219341  COMPLETED          1        1 2023-09-19T15:06:53 2023-09-19T15:06:54 2023-09-19T15:06:55            325                                                     \n           30219341.batch  COMPLETED          1        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:55            274                      814K                      814K \n          30219341.extern  COMPLETED          1        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:55            325                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(52,2,'a01c_18500101_fc0_8_CMORLPJG','2023-09-19-15:06:53','2023-09-19-15:08:20',1695128813,1695128814,1695128815,'COMPLETED',2,1,'2:00','bsc_es',324,'1850-01-01 00:00:00','CMORLPJG','fc0',8,1,'marenostrum4',30219342,'',1,4,0.0,0.0,'a01c_18500101_fc0_8_CMORLPJG.20230919150717.out','a01c_18500101_fc0_8_CMORLPJG.20230919150717.err',2,'a01c_18500101_fc0_8_POST',replace('                 30219342  COMPLETED          1        1 2023-09-19T15:06:53 2023-09-19T15:06:54 2023-09-19T15:06:55            324                                                     \n           30219342.batch  COMPLETED          1        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:55            263                      814K                      814K \n          30219342.extern  COMPLETED          1        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:55            324                      708K                      708K \n','\n',char(10)));
INSERT INTO job_data VALUES(53,2,'a01c_18500101_fc0_8_CMORTM5','2023-09-19-15:06:53','2023-09-19-15:08:22',1695128813,1695128814,1695128815,'COMPLETED',2,1,'2:00','bsc_es',324,'1850-01-01 00:00:00','CMORTM5','fc0',8,1,'marenostrum4',30219343,'',1,4,0.0,0.0,'a01c_18500101_fc0_8_CMORTM5.20230919150718.out','a01c_18500101_fc0_8_CMORTM5.20230919150718.err',2,'a01c_18500101_fc0_8_POST',replace('                 30219343  COMPLETED          1        1 2023-09-19T15:06:53 2023-09-19T15:06:54 2023-09-19T15:06:55            324                                                     \n           30219343.batch  COMPLETED          1        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:55            269                      812K                      812K \n          30219343.extern  COMPLETED          1        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:55            324                      706K                      706K \n','\n',char(10)));
INSERT INTO job_data VALUES(54,2,'a01c_18500101_fc0_8_SAVEIC','2023-09-19-15:06:53','2023-09-19-15:08:27',1695128813,1695128817,1695128818,'COMPLETED',2,12,'01:00','bsc_es',297,'1850-01-01 00:00:00','SAVEIC','fc0',8,1,'marenostrum4',30219344,'',1,4,0.0,0.0,'a01c_18500101_fc0_8_SAVEIC.20230919150723.out','a01c_18500101_fc0_8_SAVEIC.20230919150723.err',2,'a01c_18500101_fc0_8_POST',replace('                 30219344  COMPLETED         12        1 2023-09-19T15:06:53 2023-09-19T15:06:54 2023-09-19T15:06:58            297                                                     \n           30219344.batch  COMPLETED         12        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:58            253                      840K                      840K \n          30219344.extern  COMPLETED         12        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:58            297                       28K                       28K \n','\n',char(10)));
INSERT INTO job_data VALUES(55,2,'a01c_18500101_fc0_4_POST','2023-09-19-15:06:53','2023-09-19-15:08:28',1695128813,1695128816,1695128817,'COMPLETED',2,12,'01:00','bsc_es',307,'1850-01-01 00:00:00','POST','fc0',4,1,'marenostrum4',30219345,'',1,4,0.0,0.0,'a01c_18500101_fc0_4_POST.20230919150725.out','a01c_18500101_fc0_4_POST.20230919150725.err',2,'a01c_18500101_fc0_5_POST,a01c_18500101_fc0_4_CLEAN',replace('                 30219345  COMPLETED         12        1 2023-09-19T15:06:53 2023-09-19T15:06:54 2023-09-19T15:06:57            307                                                     \n           30219345.batch  COMPLETED         12        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:57            256                      932K                      932K \n          30219345.extern  COMPLETED         12        1 2023-09-19T15:06:54 2023-09-19T15:06:54 2023-09-19T15:06:57            307                       26K                       26K \n','\n',char(10)));
INSERT INTO job_data VALUES(56,2,'a01c_18500101_fc0_10_SIM','2023-09-19-15:07:25','2023-09-19-15:07:48',1695128845,1695128845,1695128846,'COMPLETED',2,1,'0:02','debug',0,'1850-01-01 00:00:00','SIM','fc0',10,1,'LOCAL',68491,'',0,4,0.0,0.0,'a01c_18500101_fc0_10_SIM.20230919150748.out','a01c_18500101_fc0_10_SIM.20230919150748.err',5,'a01c_18500101_fc0_10_CMORLPJG,a01c_18500101_fc0_10_CMOROCE,a01c_18500101_fc0_10_CMORTM5,a01c_18500101_fc0_9_CMORATM,a01c_18500101_fc0_11_SIM,a01c_18500101_fc0_10_SAVEIC','');
INSERT INTO job_data VALUES(57,2,'a01c_18500101_fc0_8_CMORATM','2023-09-19-15:07:36','2023-09-19-15:08:03',1695128856,1695128858,1695128859,'COMPLETED',2,1,'2:00','bsc_es',0,'1850-01-01 00:00:00','CMORATM','fc0',8,1,'marenostrum4',30219348,'',0,4,0.0,0.0,'a01c_18500101_fc0_8_CMORATM.20230919150802.out','a01c_18500101_fc0_8_CMORATM.20230919150802.err',5,'a01c_18500101_fc0_7_POST','');
INSERT INTO job_data VALUES(58,2,'a01c_18500101_fc0_9_CMOROCE','2023-09-19-15:07:36','2023-09-19-15:08:06',1695128856,1695128856,1695128857,'COMPLETED',2,1,'1:00','bsc_es',0,'1850-01-01 00:00:00','CMOROCE','fc0',9,1,'marenostrum4',30219349,'',0,4,0.0,0.0,'a01c_18500101_fc0_9_CMOROCE.20230919150804.out','a01c_18500101_fc0_9_CMOROCE.20230919150804.err',5,'a01c_18500101_fc0_9_POST','');
INSERT INTO job_data VALUES(59,2,'a01c_18500101_fc0_9_CMORLPJG','2023-09-19-15:07:36','2023-09-19-15:08:09',1695128856,1695128856,1695128857,'COMPLETED',2,1,'2:00','bsc_es',0,'1850-01-01 00:00:00','CMORLPJG','fc0',9,1,'marenostrum4',30219350,'',0,4,0.0,0.0,'a01c_18500101_fc0_9_CMORLPJG.20230919150809.out','a01c_18500101_fc0_9_CMORLPJG.20230919150809.err',5,'a01c_18500101_fc0_9_POST','');
INSERT INTO job_data VALUES(60,2,'a01c_18500101_fc0_9_CMORTM5','2023-09-19-15:07:36','2023-09-19-15:08:07',1695128856,1695128862,1695128863,'COMPLETED',2,1,'2:00','bsc_es',0,'1850-01-01 00:00:00','CMORTM5','fc0',9,1,'marenostrum4',30219351,'',0,4,0.0,0.0,'a01c_18500101_fc0_9_CMORTM5.20230919150807.out','a01c_18500101_fc0_9_CMORTM5.20230919150807.err',5,'a01c_18500101_fc0_9_POST','');
INSERT INTO job_data VALUES(61,2,'a01c_18500101_fc0_9_SAVEIC','2023-09-19-15:07:36','2023-09-19-15:08:13',1695128856,1695128864,1695128865,'COMPLETED',2,12,'01:00','bsc_es',0,'1850-01-01 00:00:00','SAVEIC','fc0',9,1,'marenostrum4',30219352,'',0,4,0.0,0.0,'a01c_18500101_fc0_9_SAVEIC.20230919150812.out','a01c_18500101_fc0_9_SAVEIC.20230919150812.err',5,'a01c_18500101_fc0_9_POST','');
INSERT INTO job_data VALUES(62,2,'a01c_18500101_fc0_5_POST','2023-09-19-15:07:36','2023-09-19-15:08:11',1695128856,1695128864,1695128865,'COMPLETED',2,12,'01:00','bsc_es',0,'1850-01-01 00:00:00','POST','fc0',5,1,'marenostrum4',30219353,'',0,4,0.0,0.0,'a01c_18500101_fc0_5_POST.20230919150810.out','a01c_18500101_fc0_5_POST.20230919150810.err',5,'a01c_18500101_fc0_6_POST,a01c_18500101_fc0_5_CLEAN','');
INSERT INTO job_data VALUES(63,2,'a01c_18500101_fc0_9_CMORATM','2023-09-19-15:08:20','2023-09-19-15:08:47',1695128900,1695128916,1695128917,'COMPLETED',2,1,'2:00','bsc_es',0,'1850-01-01 00:00:00','CMORATM','fc0',9,1,'marenostrum4',30219358,'',0,4,0.0,0.0,'a01c_18500101_fc0_9_CMORATM.20230919150846.out','a01c_18500101_fc0_9_CMORATM.20230919150846.err',5,'a01c_18500101_fc0_8_POST','');
INSERT INTO job_data VALUES(64,2,'a01c_18500101_fc0_10_CMOROCE','2023-09-19-15:08:20','2023-09-19-15:08:51',1695128900,1695128916,1695128917,'COMPLETED',2,1,'1:00','bsc_es',0,'1850-01-01 00:00:00','CMOROCE','fc0',10,1,'marenostrum4',30219360,'',0,4,0.0,0.0,'a01c_18500101_fc0_10_CMOROCE.20230919150851.out','a01c_18500101_fc0_10_CMOROCE.20230919150851.err',5,'a01c_18500101_fc0_10_POST','');
INSERT INTO job_data VALUES(65,2,'a01c_18500101_fc0_10_CMORLPJG','2023-09-19-15:08:20','2023-09-19-15:08:53',1695128900,1695128916,1695128917,'COMPLETED',2,1,'2:00','bsc_es',0,'1850-01-01 00:00:00','CMORLPJG','fc0',10,1,'marenostrum4',30219362,'',0,4,0.0,0.0,'a01c_18500101_fc0_10_CMORLPJG.20230919150852.out','a01c_18500101_fc0_10_CMORLPJG.20230919150852.err',5,'a01c_18500101_fc0_10_POST','');
INSERT INTO job_data VALUES(66,2,'a01c_18500101_fc0_10_CMORTM5','2023-09-19-15:08:21','2023-09-19-15:08:54',1695128900,1695128916,1695128917,'COMPLETED',2,1,'2:00','bsc_es',0,'1850-01-01 00:00:00','CMORTM5','fc0',10,1,'marenostrum4',30219363,'',0,4,0.0,0.0,'a01c_18500101_fc0_10_CMORTM5.20230919150854.out','a01c_18500101_fc0_10_CMORTM5.20230919150854.err',5,'a01c_18500101_fc0_10_POST','');
INSERT INTO job_data VALUES(67,2,'a01c_18500101_fc0_10_SAVEIC','2023-09-19-15:08:21','2023-09-19-15:08:48',1695128901,1695128919,1695128920,'COMPLETED',2,12,'01:00','bsc_es',0,'1850-01-01 00:00:00','SAVEIC','fc0',10,1,'marenostrum4',30219364,'',0,4,0.0,0.0,'a01c_18500101_fc0_10_SAVEIC.20230919150848.out','a01c_18500101_fc0_10_SAVEIC.20230919150848.err',5,'a01c_18500101_fc0_10_POST','');
INSERT INTO job_data VALUES(68,2,'a01c_18500101_fc0_6_POST','2023-09-19-15:08:21','2023-09-19-15:08:50',1695128901,1695128918,1695128919,'COMPLETED',2,12,'01:00','bsc_es',0,'1850-01-01 00:00:00','POST','fc0',6,1,'marenostrum4',30219365,'',0,4,0.0,0.0,'a01c_18500101_fc0_6_POST.20230919150849.out','a01c_18500101_fc0_6_POST.20230919150849.err',5,'a01c_18500101_fc0_7_POST,a01c_18500101_fc0_6_CLEAN','');
INSERT INTO job_data VALUES(69,2,'a01c_18500101_fc0_7_POST','2023-09-19-15:09:01','2023-09-19-15:09:01',1695128941,0,0,'SUBMITTED',2,12,'01:00','bsc_es',0,'1850-01-01 00:00:00','POST','fc0',7,1,'marenostrum4',30219368,'',0,4,0.0,0.0,'','',0,'a01c_18500101_fc0_8_POST,a01c_18500101_fc0_7_CLEAN','');
DELETE FROM sqlite_sequence;
INSERT INTO sqlite_sequence VALUES('experiment_run',13);
INSERT INTO sqlite_sequence VALUES('job_data',69);
CREATE INDEX ID_JOB_NAME ON job_data(job_name);
COMMIT;
